@@ -1,21 +1,19 @@
-# -*- coding: utf-8 -*-
-
 import os
-import six
 
 import pytest
 
 from translate.convert import convert
 
 
-class TestConvertCommand(object):
+class TestConvertCommand:
     """Tests running actual commands on files"""
+
     convertmodule = convert
     defaultoptions = {"progress": "none"}
 
     def setup_method(self, method):
         """creates a clean test directory for the given method"""
-        self.testdir = "%s_%s" % (self.__class__.__name__, method.__name__)
+        self.testdir = f"{self.__class__.__name__}_{method.__name__}"
         self.cleardir()
         os.mkdir(self.testdir)
         self.rundir = os.path.abspath(os.getcwd())
@@ -43,11 +41,11 @@ class TestConvertCommand(object):
         argv = list(argv)
         kwoptions = getattr(self, "defaultoptions", {}).copy()
         kwoptions.update(kwargs)
-        for key, value in six.iteritems(kwoptions):
+        for key, value in kwoptions.items():
             if value is True:
                 argv.append("--%s" % key)
             else:
-                argv.append("--%s=%s" % (key, value))
+                argv.append(f"--{key}={value}")
         try:
             self.convertmodule.main(argv)
         finally:
@@ -72,15 +70,15 @@ class TestConvertCommand(object):
 
     def create_testfile(self, filename, contents):
         """creates the given file in the testdirectory with the given contents"""
-        if isinstance(contents, six.text_type):
-            contents = contents.encode('utf-8')
+        if isinstance(contents, str):
+            contents = contents.encode("utf-8")
         testfile = self.open_testfile(filename, "wb")
         testfile.write(contents)
         testfile.close()
 
     def read_testfile(self, filename):
         """reads the given file in the testdirectory and returns the contents"""
-        with open(self.get_testfilename(filename), 'rb') as testfile:
+        with open(self.get_testfilename(filename), "rb") as testfile:
             content = testfile.read()
         return content
 
@@ -102,18 +100,19 @@ class TestConvertCommand(object):
             self.run_command(help=True)
         help_string, err = capsys.readouterr()
         # normalize newlines
-        help_string = help_string.replace('\r\n', '\n').replace('\r', '\n')
+        help_string = help_string.replace("\r\n", "\n").replace("\r", "\n")
         convertsummary = self.convertmodule.__doc__.split("\n")[0]
         # the convertsummary might be wrapped. this will probably unwrap it
         assert convertsummary in help_string.replace("\n", " ")
-        usageline = help_string[:help_string.find("\n")]
+        usageline = help_string[: help_string.find("\n")]
         # Different versions of optparse might contain either upper or
         # lowercase versions of 'Usage:' and 'Options:', so we need to take
         # that into account
-        assert (usageline.startswith("Usage: ") or usageline.startswith("usage: ")) \
-            and "[--version] [-h|--help]" in usageline
-        options = help_string[help_string.find("ptions:\n"):]
-        options = options[options.find("\n")+1:]
+        assert (
+            usageline.startswith("Usage: ") or usageline.startswith("usage: ")
+        ) and "[--version] [-h|--help]" in usageline
+        options = help_string[help_string.find("ptions:\n") :]
+        options = options[options.find("\n") + 1 :]
         options = self.help_check(options, "--progress=PROGRESS")
         options = self.help_check(options, "--version")
         options = self.help_check(options, "-h, --help")
