@@ -20,7 +20,7 @@ class TestOO2POCommand(test_convert.TestConvertCommand, TestOO2XLIFF):
 
     def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self, capsys)
+        options = super().test_help(capsys)
         options = self.help_check(options, "--source-language=LANG")
         options = self.help_check(options, "--language=LANG")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE")
