@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 #
@@ -22,6 +21,7 @@
 .. seealso:: http://en.wikipedia.org/wiki/Amharic_language
 """
 
+
 import re
 
 from translate.lang import common
@@ -30,22 +30,26 @@ from translate.lang import common
 class am(common.Common):
     """This class represents Amharic."""
 
-    listseperator = u"፣ "
+    listseperator = "፣ "
 
-    sentenceend = u"።!?…"
+    sentenceend = "።!?…"
 
-    sentencere = re.compile(r"""(?s)    #make . also match newlines
+    sentencere = re.compile(
+        r"""(?s)    #make . also match newlines
                             .*?         #anything, but match non-greedy
                             [%s]        #the puntuation for sentence ending
                             \s*         #optional spacing after the puntuation
-                            """ % sentenceend, re.VERBOSE)
+                            """
+        % sentenceend,
+        re.VERBOSE,
+    )
 
     puncdict = {
-        u".": u"።",
-        u";": u"፤",
-        u",": u"፣",
+        ".": "።",
+        ";": "፤",
+        ",": "፣",
     }
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
