@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007, 2016 Zuza Software Foundation
 #
@@ -22,6 +21,7 @@
 .. seealso:: https://en.wikipedia.org/wiki/Odia_language
 """
 
+
 import re
 
 from translate.lang import common
@@ -30,20 +30,24 @@ from translate.lang import common
 class code_or(common.Common):
     """This class represents Odia."""
 
-    sentenceend = u"।!?…"
+    sentenceend = "।!?…"
 
-    sentencere = re.compile(r"""(?s)    #make . also match newlines
+    sentencere = re.compile(
+        r"""(?s)    #make . also match newlines
                             .*?         #anything, but match non-greedy
                             [%s]        #the puntuation for sentence ending
                             \s+         #the spacing after the puntuation
                             (?=[^a-z\d])#lookahead that next part starts with caps
-                            """ % sentenceend, re.VERBOSE)
+                            """
+        % sentenceend,
+        re.VERBOSE,
+    )
 
     puncdict = {
-        u". ": u"। ",
-        u".\n": u"।\n",
+        ". ": "। ",
+        ".\n": "।\n",
     }
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
