@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 #
 # Copyright 2005, 2006 Zuza Software Foundation
 #
@@ -37,39 +35,93 @@ def main():
     """main program for pydiff"""
     parser = ArgumentParser()
     # GNU diff like options
-    parser.add_argument("-i", "--ignore-case", default=False, action="store_true",
-                        help='Ignore case differences in file contents.')
-    parser.add_argument("-U", "--unified", type=int, metavar="NUM", default=3,
-                        dest="unified_lines",
-                        help='Output NUM (default %(default)s) lines of unified context')
-    parser.add_argument("-r", "--recursive", default=False, action="store_true",
-                        help='Recursively compare any subdirectories found.')
-    parser.add_argument("-N", "--new-file", default=False, action="store_true",
-                        help='Treat absent files as empty.')
-    parser.add_argument("--unidirectional-new-file", default=False,
-                        action="store_true",
-                        help='Treat absent first files as empty.')
-    parser.add_argument("-s", "--report-identical-files", default=False,
-                        action="store_true",
-                        help='Report when two files are the same.')
-    parser.add_argument("-x", "--exclude", default=["CVS", "*.po~"],
-                        action="append", metavar="PAT",
-                        help='Exclude files that match PAT.')
+    parser.add_argument(
+        "-i",
+        "--ignore-case",
+        default=False,
+        action="store_true",
+        help="Ignore case differences in file contents.",
+    )
+    parser.add_argument(
+        "-U",
+        "--unified",
+        type=int,
+        metavar="NUM",
+        default=3,
+        dest="unified_lines",
+        help="Output NUM (default %(default)s) lines of unified context",
+    )
+    parser.add_argument(
+        "-r",
+        "--recursive",
+        default=False,
+        action="store_true",
+        help="Recursively compare any subdirectories found.",
+    )
+    parser.add_argument(
+        "-N",
+        "--new-file",
+        default=False,
+        action="store_true",
+        help="Treat absent files as empty.",
+    )
+    parser.add_argument(
+        "--unidirectional-new-file",
+        default=False,
+        action="store_true",
+        help="Treat absent first files as empty.",
+    )
+    parser.add_argument(
+        "-s",
+        "--report-identical-files",
+        default=False,
+        action="store_true",
+        help="Report when two files are the same.",
+    )
+    parser.add_argument(
+        "-x",
+        "--exclude",
+        default=["CVS", "*.po~"],
+        action="append",
+        metavar="PAT",
+        help="Exclude files that match PAT.",
+    )
     # our own options
-    parser.add_argument("--fromcontains", type=str, default=None,
-                        metavar="TEXT",
-                        help='Only show changes where fromfile contains TEXT')
-    parser.add_argument("--tocontains", type=str, default=None,
-                        metavar="TEXT",
-                        help='Only show changes where tofile contains TEXT')
-    parser.add_argument("--contains", type=str, default=None,
-                        metavar="TEXT",
-                        help='Only show changes where fromfile or tofile contains TEXT')
-    parser.add_argument("-I", "--ignore-case-contains", default=False, action="store_true",
-                        help='Ignore case differences when matching any of the changes')
-    parser.add_argument("--accelerator", dest="accelchars", default="",
-                        metavar="ACCELERATORS",
-                        help="ignores the given accelerator characters when matching")
+    parser.add_argument(
+        "--fromcontains",
+        type=str,
+        default=None,
+        metavar="TEXT",
+        help="Only show changes where fromfile contains TEXT",
+    )
+    parser.add_argument(
+        "--tocontains",
+        type=str,
+        default=None,
+        metavar="TEXT",
+        help="Only show changes where tofile contains TEXT",
+    )
+    parser.add_argument(
+        "--contains",
+        type=str,
+        default=None,
+        metavar="TEXT",
+        help="Only show changes where fromfile or tofile contains TEXT",
+    )
+    parser.add_argument(
+        "-I",
+        "--ignore-case-contains",
+        default=False,
+        action="store_true",
+        help="Ignore case differences when matching any of the changes",
+    )
+    parser.add_argument(
+        "--accelerator",
+        dest="accelchars",
+        default="",
+        metavar="ACCELERATORS",
+        help="ignores the given accelerator characters when matching",
+    )
     parser.add_argument("fromfile", nargs=1)
     parser.add_argument("tofile", nargs=1)
     args = parser.parse_args()
@@ -82,12 +134,16 @@ def main():
         if os.path.isdir(tofile):
             differ = DirDiffer(fromfile, tofile, args)
         else:
-            parser.error("File %s is a directory while file %s is a regular file" %
-                         (fromfile, tofile))
+            parser.error(
+                "File %s is a directory while file %s is a regular file"
+                % (fromfile, tofile)
+            )
     else:
         if os.path.isdir(tofile):
-            parser.error("File %s is a regular file while file %s is a directory" %
-                         (fromfile, tofile))
+            parser.error(
+                "File %s is a regular file while file %s is a directory"
+                % (fromfile, tofile)
+            )
         else:
             differ = FileDiffer(fromfile, tofile, args)
     differ.writediff(sys.stdout)
@@ -120,9 +176,12 @@ class DirDiffer:
         for difffile in difffiles:
             if self.isexcluded(difffile):
                 continue
-            from_ok = (difffile in fromfiles or self.options.new_file or
-                       self.options.unidirectional_new_file)
-            to_ok = (difffile in tofiles or self.options.new_file)
+            from_ok = (
+                difffile in fromfiles
+                or self.options.new_file
+                or self.options.unidirectional_new_file
+            )
+            to_ok = difffile in tofiles or self.options.new_file
             if from_ok and to_ok:
                 fromfile = os.path.join(self.fromdir, difffile)
                 tofile = os.path.join(self.todir, difffile)
@@ -132,22 +191,28 @@ class DirDiffer:
                             differ = DirDiffer(fromfile, tofile, self.options)
                             differ.writediff(outfile)
                         else:
-                            outfile.write("Common subdirectories: %s and %s\n" %
-                                          (fromfile, tofile))
+                            outfile.write(
+                                "Common subdirectories: %s and %s\n"
+                                % (fromfile, tofile)
+                            )
                     else:
-                        outfile.write("File %s is a directory while file %s is a regular file\n" %
-                                      (fromfile, tofile))
+                        outfile.write(
+                            "File %s is a directory while file %s is a regular file\n"
+                            % (fromfile, tofile)
+                        )
                 else:
                     if os.path.isdir(tofile):
-                        parser.error("File %s is a regular file while file %s is a directory\n" %
-                                     (fromfile, tofile))
+                        outfile.write(
+                            "File %s is a regular file while file %s is a directory\n"
+                            % (fromfile, tofile)
+                        )
                     else:
                         filediffer = FileDiffer(fromfile, tofile, self.options)
                         filediffer.writediff(outfile)
             elif from_ok:
-                outfile.write("Only in %s: %s\n" % (self.fromdir, difffile))
+                outfile.write(f"Only in {self.fromdir}: {difffile}\n")
             elif to_ok:
-                outfile.write("Only in %s: %s\n" % (self.todir, difffile))
+                outfile.write(f"Only in {self.todir}: {difffile}\n")
 
 
 class FileDiffer:
@@ -165,7 +230,7 @@ class FileDiffer:
         """writes the actual diff to the given file"""
         validfiles = True
         if os.path.exists(self.fromfile):
-            with open(self.fromfile, 'U') as fh:
+            with open(self.fromfile) as fh:
                 self.from_lines = fh.readlines()
             fromfiledate = os.stat(self.fromfile).st_mtime
         elif self.fromfile == "-":
@@ -178,7 +243,7 @@ class FileDiffer:
             outfile.write("%s: No such file or directory\n" % self.fromfile)
             validfiles = False
         if os.path.exists(self.tofile):
-            with open(self.tofile, 'U') as fh:
+            with open(self.tofile) as fh:
                 self.to_lines = fh.readlines()
             tofiledate = os.stat(self.tofile).st_mtime
         elif self.tofile == "-":
@@ -202,14 +267,16 @@ class FileDiffer:
         matcher = difflib.SequenceMatcher(None, compare_from_lines, compare_to_lines)
         groups = matcher.get_grouped_opcodes(self.options.unified_lines)
         started = False
-        fromstring = '--- %s\t%s%s' % (self.fromfile, fromfiledate, lineterm)
-        tostring = '+++ %s\t%s%s' % (self.tofile, tofiledate, lineterm)
+        fromstring = f"--- {self.fromfile}\t{fromfiledate}{lineterm}"
+        tostring = f"+++ {self.tofile}\t{tofiledate}{lineterm}"
 
         for group in groups:
-            hunk = "".join([line for line in self.unified_diff(group)])
+            hunk = "".join(line for line in self.unified_diff(group))
             if self.options.fromcontains:
                 if self.options.ignore_case_contains:
-                    hunk_from_lines = "".join([line.lower() for line in self.get_from_lines(group)])
+                    hunk_from_lines = "".join(
+                        line.lower() for line in self.get_from_lines(group)
+                    )
                 else:
                     hunk_from_lines = "".join(self.get_from_lines(group))
                 for accelerator in self.options.accelchars:
@@ -218,7 +285,9 @@ class FileDiffer:
                     continue
             if self.options.tocontains:
                 if self.options.ignore_case_contains:
-                    hunk_to_lines = "".join([line.lower() for line in self.get_to_lines(group)])
+                    hunk_to_lines = "".join(
+                        line.lower() for line in self.get_to_lines(group)
+                    )
                 else:
                     hunk_to_lines = "".join(self.get_to_lines(group))
                 for accelerator in self.options.accelchars:
@@ -227,9 +296,15 @@ class FileDiffer:
                     continue
             if self.options.contains:
                 if self.options.ignore_case_contains:
-                    hunk_lines = "".join([line.lower() for line in self.get_from_lines(group) + self.get_to_lines(group)])
+                    hunk_lines = "".join(
+                        line.lower()
+                        for line in self.get_from_lines(group)
+                        + self.get_to_lines(group)
+                    )
                 else:
-                    hunk_lines = "".join(self.get_from_lines(group) + self.get_to_lines(group))
+                    hunk_lines = "".join(
+                        self.get_from_lines(group) + self.get_to_lines(group)
+                    )
                 for accelerator in self.options.accelchars:
                     hunk_lines = hunk_lines.replace(accelerator, "")
                 if self.options.contains not in hunk_lines:
@@ -240,8 +315,7 @@ class FileDiffer:
                 started = True
             outfile.write(hunk)
         if not started and self.options.report_identical_files:
-            outfile.write("Files %s and %s are identical\n" %
-                          (self.fromfile, self.tofile))
+            outfile.write(f"Files {self.fromfile} and {self.tofile} are identical\n")
 
     def get_from_lines(self, group):
         """returns the lines referred to by group, from the fromfile"""
@@ -264,16 +338,16 @@ class FileDiffer:
         i1, i2, j1, j2 = group[0][1], group[-1][2], group[0][3], group[-1][4]
         yield "@@ -%d,%d +%d,%d @@%s" % (i1 + 1, i2 - i1, j1 + 1, j2 - j1, lineterm)
         for tag, i1, i2, j1, j2 in group:
-            if tag == 'equal':
+            if tag == "equal":
                 for line in self.from_lines[i1:i2]:
-                    yield ' ' + line
+                    yield " " + line
                 continue
-            if tag == 'replace' or tag == 'delete':
+            if tag == "replace" or tag == "delete":
                 for line in self.from_lines[i1:i2]:
-                    yield '-' + line
-            if tag == 'replace' or tag == 'insert':
+                    yield "-" + line
+            if tag == "replace" or tag == "insert":
                 for line in self.to_lines[j1:j2]:
-                    yield '+' + line
+                    yield "+" + line
 
 
 if __name__ == "__main__":
